@@ -3,12 +3,10 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.06'; # VERSION
+our $VERSION = '1.07'; # VERSION
 
 use base 'Pod::Parser';
 
-use constant MAXWORDLENGTH => 50; ## no critic ( ProhibitConstantPragma )
-
 use Pod::Wordlist;
 use Pod::Escapes ('e2char');
 use Text::Wrap   ('wrap');
@@ -29,18 +27,18 @@ sub new {
 
 	my $new = $class->SUPER::new( %args );
 
-	$new->{'spell_stopwords'} = {};
-
-	$new->{'spell_stopwords'}
-		= \%Pod::Wordlist::Wordlist; ## no critic ( ProhibitPackageVars )
-
 	$new->{'region'} = [];
 
 	$new->{debug} = $args{debug};
 
+	$new->{stopwords}
+		= $args{stopwords} || Pod::Wordlist->new( _is_debug => $args{debug} );
+
 	return $new;
 }
 
+sub stopwords { my $self = shift; return $self->{stopwords} }
+
 sub verbatim { return ''; }    # totally ignore verbatim sections
 
 #----------------------------------------------------------------------
@@ -51,27 +49,6 @@ sub _is_debug {
 	return $self->{debug} ? 1 : 0;
 }
 
-sub _get_stopwords_from {
-	my ( $self, $text ) = @_;
-	my $stopwords = $self->{'spell_stopwords'};
-
-	while ( $text =~ m<(\S+)>g ) {
-		my $word = $1;
-		if ( $word =~ m/^!(.+)/s ) {
-			# "!word" deletes from the stopword list
-			my $negation = $1;
-			# different $1 from above
-			delete $stopwords->{$negation};
-			print "Unlearning stopword $word\n" if $self->_is_debug;
-		}
-		else {
-			$stopwords->{$word} = 1;
-			print "Learning stopword $1\n" if $self->_is_debug;
-		}
-	}
-	return;
-}
-
 #----------------------------------------------------------------------
 
 sub textblock {
@@ -83,11 +60,11 @@ sub textblock {
 			= $self->{'region'}[-1];
 
 		if ( $last_region eq 'stopwords' ) {
-			$self->_get_stopwords_from($paragraph);
+			$self->stopwords->learn_stopwords($paragraph);
 			return;
 		}
 		elsif ( $last_region eq ':stopwords' ) {
-			$self->_get_stopwords_from( $self->interpolate($paragraph) );
+			$self->stopwords->learn_stopwords( $self->interpolate($paragraph) );
 
 			# I guess that'd work.
 			return;
@@ -135,7 +112,7 @@ sub command { ## no critic ( ArgUnpacking)
 			my $para = $2;
 			$para = $self->interpolate($para) if $1;
 			print "Stopword para: <$2>\n" if $self->_is_debug;
-			$self->_get_stopwords_from($para);
+			$self->stopwords->learn_stopwords($para);
 		}
 	}
 	elsif ( @{ $self->{'region'} } ) {    # TODO: accept POD formatting
@@ -203,64 +180,15 @@ sub interior_sequence { ## no critic ( Subroutines::RequireFinalReturn )
 	}
 }
 
-#==========================================================================
-# The guts:
-
-sub _treat_words {    ## no critic ( Subroutines::RequireArgUnpacking )
-	my $self = shift;
-
-	# Count the things in $_[0]
-	print "Content: <", $_[0], ">\n" if $self->_is_debug;
-
-	my $stopwords = $self->{'spell_stopwords'};
-	my $word;
-	$_[0] =~ tr/\xA0\xAD/ /d;
-
-	# i.e., normalize non-breaking spaces, and delete soft-hyphens
-
-	my $out = '';
-
-	my ( $leading, $trailing );
-	while ( $_[0] =~ m<(\S+)>g ) {
-
-		# Trim normal English punctuation, if leading or trailing.
-		next if length $1 > MAXWORDLENGTH;
-		$word = $1;
-		if   ( $word =~ s/^([\`\"\'\(\[])//s ) { $leading = $1 }
-		else                                   { $leading = '' }
-
-		if   ( $word =~ s/([\)\]\'\"\.\:\;\,\?\!]+)$//s ) { $trailing = $1 }
-		else                                              { $trailing = '' }
-
-		if (
-			$word =~ m/^[\&\%\$\@\:\<\*\\\_]/s
-
-			# if it looks like it starts with a sigil, etc.
-			or $word =~ m/[\%\^\&\#\$\@\_\<\>\(\)\[\]\{\}\\\*\:\+\/\=\|\`\~]/
-
-			# or contains anything strange
-		  )
-		{
-			print "rejecting {$word}\n" if $self->_is_debug && $word ne '_';
-			next;
-		}
-		else {
-			if ( exists $stopwords->{$word} or exists $stopwords->{ lc $word } )
-			{
-				print " [Rejecting \"$word\" as a stopword]\n"
-					if $self->_is_debug;
-			}
-			else {
-				$out .= "$leading$word$trailing ";
-			}
-		}
-	}
+#--------------------------------------------------------------------------
 
+sub _treat_words {
+	my ($self, $text) = @_;
+	my $out = $self->stopwords->strip_stopwords( $text );
 	if ( length $out ) {
 		my $out_fh = $self->output_handle();
 		print $out_fh wrap( '', '', $out ), "\n\n";
 	}
-
 	return;
 }
 
@@ -280,7 +208,7 @@ Pod::Spell - a formatter for spellchecking Pod
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -332,6 +260,10 @@ C<"=for stopwords"> / C<"=for :stopwords"> region(s) in a document.
 
 =head2 verbatim
 
+=head2 stopwords
+
+	$self->stopwords->isa('Pod::WordList'); # true
+
 =head1 ADDING STOPWORDS
 
 You can add stopwords on a per-document basis with
@@ -344,7 +276,8 @@ This adds every word in that paragraph after "stopwords" to the
 stopword list, effective for the rest of the document.  In such a
 list, words are whitespace-separated.  (The amount of whitespace
 doesn't matter, as long as there's no blank lines in the middle
-of the paragraph.)  Words beginning with "!" are
+of the paragraph.)  Plural forms are added automatically using
+L<Lingua::EN::Inflect>. Words beginning with "!" are
 I<deleted> from the stopword list -- so "!qux" deletes "qux" from the
 stopword list, if it was in there in the first place.  Note that if
 a stopword is all-lowercase, then it means that it's okay in I<any>
@@ -452,6 +385,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 CONTRIBUTOR
+
+David Golden <dagolden@cpan.org>
+
 =head1 AUTHORS
 
 =over 4
